###  adapted from code posted by Matt Cooper. However, significant revisions made to match the polynomial regression formulae that appear in Appendix B of The Diagnosis, Evaluation, and Treatment of High Blood Pressure in Children and Adolescents 4th edition from the NIH NHLBI  at http://www.nhlbi.nih.gov/health/prof/heart/hbp/hbp_ped.pdf ###

bp_z <- function (data, male="M", female="F", sbp="sbp", dbp="dbp", zht="zht", age="age", sex="sex",  age.month=F)
  {
# Default values for males and females are "M" and "F" respectively, which can be amended
# Key variable names are assumed to be all in lower case, which can be amended

# Pulling out required data 

  if(age.month==F){age <- round(data[,age],1)} else {age <- round(data[,age]/12,1)} # in months
  z_ht <- data[,zht]
  sbp <- data[,sbp]
  dbp <- data[,dbp]
  sex <- data[,sex]
  sbp_z <- vector()
  dbp_z <- vector() 

# height in cm
# age will be rounded to closest value in LMS table tabulated at half integer intervals.
# You may also round age via your own rule prior to submitting and set age.month to TRUE

# Function checks

  if(any(age < (2) | age > (18))) stop("You have one or more subjects in your dataset younger than 2 years or older than 18 years, please remove and resubmit.", call.=F)

# Load regression coefficients from Appendix B
source("table_BPcoefficients.R")

# Loop to calculate z-score for sbp

  for(i in 1:nrow(data))
    {
      # Females
      if(sex[i]==female)
        {
        mu <- bplu$sbpf[1] +
        sum(bplu$sbpf[2]*(age[i]-10),bplu$sbpf[3]*(age[i]-10)^2,bplu$sbpf[4]*(age[i]-10)^3,bplu$sbpf[5]*(age[i]-10)^4) +
        sum(bplu$sbpf[6]*z_ht[i],bplu$sbpf[7]*z_ht[i]^2,bplu$sbpf[8]*z_ht[i]^3,bplu$sbpf[9]*z_ht[i]^4)
        sbp_z[i] <- (sbp[i] - mu)/bplu$sbpf[10]
        }
      # Males
      if(sex[i]==male)
        {
        mu <- bplu$sbpm[1] +
        sum(bplu$sbpm[2]*(age[i]-10),bplu$sbpm[3]*(age[i]-10)^2,bplu$sbpm[4]*(age[i]-10)^3,bplu$sbpm[5]*(age[i]-10)^4) + 
        sum(bplu$sbpm[6]*z_ht[i],bplu$sbpm[7]*z_ht[i]^2,bplu$sbpm[8]*z_ht[i]^3,bplu$sbpm[9]*z_ht[i]^4)
        sbp_z[i] <- (sbp[i] - mu)/bplu$sbpm[10]
        }
      }
  sbp_z <- round(replace(sbp_z, sbp_z=="",NA),2)

# Loop to calculate z-score for dbp

  for(i in 1:nrow(data))
    {
      # Females
      if(sex[i]==female)
        {
        mu <- bplu$dbpf[1] +
        sum(bplu$dbpf[2]*(age[i]-10), bplu$dbpf[3]*(age[i]-10)^2, bplu$dbpf[4]*(age[i]-10)^3, bplu$dbpf[5]*(age[i]-10)^4) +
        sum(bplu$dbpf[6]*z_ht[i], bplu$dbpf[7]*z_ht[i]^2, bplu$dbpf[8]*z_ht[i]^3, bplu$dbpf[9]*z_ht[i]^4)
        dbp_z[i] <- (dbp[i] - mu)/bplu$dbpf[10]
        }
      # Males
      if(sex[i]==male)
        {
        mu <- bplu$dbpm[1] +
        sum(bplu$dbpm[2]*(age[i]-10), bplu$dbpm[3]*(age[i]-10)^2, bplu$dbpm[4]*(age[i]-10)^3, bplu$dbpm[5]*(age[i]-10)^4) + 
        sum(bplu$dbpm[6]*z_ht[i], bplu$dbpm[7]*z_ht[i]^2, bplu$dbpm[8]*z_ht[i]^3, bplu$dbpm[9]*z_ht[i]^4)
        dbp_z[i] <- (dbp[i] - mu)/bplu$dbpm[10]
        }
      }
  dbp_z <- round(replace(dbp_z, dbp_z=="",NA),2)

return(cbind(sbp_z,dbp_z))
  }