# mhtp and fhtp = CDC LMS tables by 1/2 month intervals
# age.month=FALSE if age in years; height.m=TRUE if height in meters

# adapted from code posted by Matt Cooper.Based on polynomial regression formulae that appear in Appendix B of The Diagnosis, Evaluation, and Treatment of High Blood Pressure in Children and Adolescents 4th edition from the NIH NHLBI  at http://www.nhlbi.nih.gov/health/prof/heart/hbp/hbp_ped.pdf #
# Growth charts and LMS tables from
#   http://www.cdc.gov/growthcharts/percentile_data_files.htm
#   http://www.cdc.gov/growthcharts/clinical_charts.htm


ht_z <- function (data, male="M", female="F", height="height", age="age", sex="sex", age.month=F, height.m=F)
  {

# Default values for males and females are "M" and "F" respectively, this can be amended by the user
# Key variable names are assumed to be all in lower case, this can be amended by the user

# Pulling out required data into vectors
  if(age.month==F){age <- round(data[,age]*12,1)}else {age<-data[,age]} # in months, fixed error with ELSE
  ht <- data[,height]
  if(height.m==T) ht <- ht*100
  sex <- data[,sex]
  height_z <- vector()


# height in cm
# age will be rounded to nearest half-integer value in LMS tables. 
# if you feel this is not appropriate then please round your ages to those in the table (24.5, 25.5, 26.5 etc) via your own rule prior to submitting and set age.month to TRUE

# Function checks

# Load LMS tables
source("table_LMS.R")

# Loop to calculate height Z score

  for(i in 1:nrow(data))
    {
      # Females
      if(sex[i]==female & !is.na(sex[i]))
        {
        # temp <- sum(ht[i] >= fhtp[which.min(abs(age[i]-fhtp[,1])),2:10])     
        # height_perc[i] <- names(fhtp)[1+temp]
        temp <- fhtp[which.min(abs(age[i]-fhtp[,1])),2:4] # LMS data for the right row
        height_z[i] <- (((ht[i]/temp$M)^temp$L)-1)/(temp$L*temp$S)
        }
      # Males
      if(sex[i]==male & !is.na(sex[i]))
        {
        temp <- mhtp[which.min(abs(age[i]-mhtp[,1])),2:4] # LMS data for the right row
        height_z[i] <- (((ht[i]/temp$M)^temp$L)-1)/(temp$L*temp$S)
        }
      }

  height_z <- replace(height_z, height_z=="",NA)
  height_z <- replace(height_z, age < 24,NA)
  height_z <- replace(height_z, age > 216,NA)

  return(round(height_z,2))
  }