##############################################################################
## Z scores for SBP and DBP based on NIH/CDC norms for ages 2-18y           ## 
## Height Z scores from CDC 2000 charts                                     ##
## Questions: see code files or write atul.sharma@umanitoba.ca              ##
##############################################################################

## Reference:
## The Diagnosis, Evaluation, and Treatment of High Blood Pressure in Children and Adolescents 4th edition at http://www.nhlbi.nih.gov/health/prof/heart/hbp/hbp_ped.pd
## For details, see Appendix B in hpd_ped.pdf in macro folder

# set path to directory with BP files
setwd("~/Desktop/WHO/BPz")

source("Calc_HtZv1.R") #  calc CDC Ht Z  
source("Calc_BPZv1.R") # calc NHLBI BP Z using CDC HtZ


# read in spreadsheet with age (months), height (cm), and Sex (by default = M/F)
d<-read.csv("sample.csv");
d # display data


# calculate CDC Ht Z
d$htZ<-ht_z(data=d, male="M", female="F", height="height", age="agemons", sex="sex", age.month=TRUE, height.m=F)
d # display data with Ht Z

# use CDC Ht Z to calculate BP Z
tmp<-bp_z(d, male="M", female="F", sbp="sbp", dbp="dbp", zht="htZ", age="agemons", sex="sex",  age.month=T);
head(tmp) # display BP Z scores

# add BP Z to dataset
d<-cbind(d, tmp);
d
write.csv(d, "calculations.csv", row.names=FALSE) # write to spreadsheet

