##############################################################################
## Z scores for SBP and DBP based on NIH/CDC norms for ages 2-18y           ## 
## Height Z scores from CDC 2000 charts                                     ##
## Questions: see code files or write atul.sharma@umanitoba.ca              ##
##############################################################################

## Reference:
## The Diagnosis, Evaluation, and Treatment of High Blood Pressure in Children and Adolescents 4th edition at http://www.nhlbi.nih.gov/health/prof/heart/hbp/hbp_ped.pd
## For details, see Appendix B in hpd_ped.pdf in macro folder

# set path to directory with BP files
setwd("~/Desktop/WHO/BPz")

source("Calc_HtZv1.R") #  calc CDC Ht Z  
source("Calc_BPZv1.R") # calc NHLBI BP Z using CDC HtZ


# read in spreadsheet with age (months), height (cm), and Sex (by default = M/F)
d<-read.csv("~/Desktop/NHANES2016/BP Jan 28/Jan 30_Dan/out_toddlers_BPQuery_shiny.csv");head(d);dim(d)
summary(d$agemons)
d$YR<-cut(d$agemons/12, breaks=seq(2,5), labels=seq(2,4,1), include.right=TRUE);summary(d$YR)
head(d) # display data


# calculate CDC Ht Z
d$htZ<-ht_z(data=d, male="M", female="F", height="height", age="agemons", sex="sex", age.month=TRUE, height.m=F)
head(d) # display data with Ht Z

# use CDC Ht Z to calculate BP Z
tmp<-bp_z(d, male="M", female="F", sbp="sbp", dbp="dbp", zht="htZ", age="agemons", sex="sex",  age.month=T);
head(tmp) # display BP Z scores
colnames(tmp)<-c("CDC_sbpz",  "CDC_dbpz")

# add BP Z to dataset
d<-cbind(d, tmp);
head(d)


# use WHO Ht Z (zlen) to calculate BP Z
tmp<-bp_z(d, male="M", female="F", sbp="sbp", dbp="dbp", zht="zlen", age="agemons", sex="sex",  age.month=T);
head(tmp) # display BP Z scores
colnames(tmp)<-c("WHO_sbpz",  "WHO_dbpz")

# add BP Z to dataset
d<-cbind(d, tmp);
head(d)

write.csv(d, "~/Desktop/NHANES2016/BP Jan 28/Jan 30_Dan/out_toddlers_BPz.csv", row.names=FALSE) # write to spreadsheet


with(d, bagg(zlen, htZ)) # WHO_htZ - CDC_htZ
with(d, bagg(WHO_sbpz, CDC_sbpz))
with(d, bagg(WHO_dbpz, CDC_dbpz))

with(d, tapply(sbp, YR, describe ))
with(d, tapply(dbp, YR, describe ))



dx<-read.csv("~/Desktop/NHANES2016/BP Jan 28/out_NHANESBP_Jan29.csv");
# summary(d)
dx$agegrp<-factor(ifelse(dx$AGEMO<=60, "toddler","schoolage"))
summary(dx$agegrp)
dx$YR<-cut(dx$AGEMO, breaks=seq(24,216,12),labels=seq(2,17,1), include.lowest=TRUE); 
young<-subset(dx, agegrp=="toddler")

par(mfrow=c(1,2))
hist(dx$SBP, main="SBP NHANES toddlers", xlab="SBP");hist(d$sbp, main="SBP UBC toddlers", xlab="SBP")
hist(dx$DBP, main="DBP NHANES toddlers", xlab="DBP");hist(d$dbp, main="DBP UBC toddlers", xlab="DBP")

t.test(dx$SBP, d$sbp)
t.test(dx$DBP, d$dbp)

t.test(dx$SBP, d$sbp)
t.test(subset(dx, YR==2)$SBP, subset(d, YR==2)$sbp)
t.test(subset(dx, YR==3)$SBP, subset(d, YR==3)$sbp)
t.test(subset(dx, YR==4)$SBP, subset(d, YR==4)$sbp)

t.test(subset(dx, YR==2)$DBP, subset(d, YR==2)$dbp)
t.test(subset(dx, YR==3)$DBP, subset(d, YR==3)$dbp)
t.test(subset(dx, YR==4)$DBP, subset(d, YR==4)$dbp)
