##############################################################################
## Z scores for SBP and DBP based on NIH/CDC norms for ages 2-18y           ## 
## Height Z scores from CDC 2000 charts                                     ##
## Questions: see code files or write atul.sharma@umanitoba.ca              ##
##############################################################################

## Reference:
## The Diagnosis, Evaluation, and Treatment of High Blood Pressure in Children and Adolescents 4th edition at http://www.nhlbi.nih.gov/health/prof/heart/hbp/hbp_ped.pd
## For details, see Appendix B in hpd_ped.pdf in macro folder

# set path to directory with BP files
setwd("~/Desktop/WHO/BPz")

source("Calc_HtZv1.R") #  calc CDC Ht Z  
source("Calc_BPZv1.R") # calc NHLBI BP Z using CDC HtZ

# read in spreadsheet with age (months), height (cm), and Sex (by default = M/F)
d<-read.csv("~/Desktop/NHANES2016/BP Jan 28/NHANESBP.csv");
head(d) # display data

# calculate CDC Ht Z
d$CDC_htZ<-ht_z(data=d, male="1", female="2", height="HEIGHT", age="AGEMO", sex="SEX", age.month=TRUE, height.m=F)
head(d) # display data with Ht Z

# use CDC Ht Z to calculate BP Z
tmp<-bp_z(d, male="1", female="2", sbp="SBP", dbp="DBP", zht="CDC_htZ", age="AGEMO", sex="SEX",  age.month=T);
head(tmp) # display BP Z scores
dim(tmp)
colnames(tmp)<-c("CDC_sbp_z", "CDC_dbp_z")
d<-cbind(d,tmp)

write.csv(d, "~/Desktop/NHANES2016/BP Jan 28/NHANESBP.csv", row.names=FALSE);
# plot(CDC_sbp_z~CDC_dbp_z, data=d)
# 
# with(d, cor.test(CDC_sbp_z, CDC_dbp_z))



# calculate in Shiny app WHO Ht Z

# read in spreadsheet with age (months), height (cm), and Sex (by default = M/F)
d1<-read.csv("~/Desktop/NHANES2016/BP Jan 28/out_NHANESBP_shiny.csv");head(d1)
d2<-read.csv("~/Desktop/NHANES2016/BP Jan 28/NHANESBP.csv");head(d2)
d<-merge(d1, d2, by.x="id", by.y="ID");head(d)


# use WHO Ht Z to calculate BP Z
tmp<-bp_z(d, male="1", female="2", sbp="SBP", dbp="DBP", zht="WHO_htZ", age="AGEMO", sex="SEX",  age.month=T);
head(tmp) # display BP Z scores
dim(tmp)
colnames(tmp)<-c("WHO_sbp_z", "WHO_dbp_z")
d<-cbind(d,tmp)

write.csv(d, "~/Desktop/NHANES2016/BP Jan 28/NHANESBP.csv", row.names=FALSE); #overwrite

#################
d<-read.csv("~/Desktop/NHANES2016/BP Jan 28/NHANESBP.csv");head(d)
plot(CDC_sbp_z~WHO_sbp_z, data=d)
with(d, cor.test(CDC_sbp_z,WHO_sbp_z))

plot(CDC_htZ~WHO_htZ, data=d)

with(d, cor.test(CDC_htZ, WHO_htZ))

