##############################################################################
## Z scores for SBP and DBP based on NIH/CDC norms for ages 2-18y           ## 
## Height Z scores from CDC 2000 charts                                     ##
## Questions: see code files or write atul.sharma@umanitoba.ca              ##
##############################################################################

## Reference:
## The Diagnosis, Evaluation, and Treatment of High Blood Pressure in Children and Adolescents 4th edition at http://www.nhlbi.nih.gov/health/prof/heart/hbp/hbp_ped.pd
## For details, see Appendix B in hpd_ped.pdf in macro folder

# set path to directory with BP files
setwd("~/Desktop/WHO/BPz")

source("Calc_HtZv1.R") #  calc CDC Ht Z  
source("Calc_BPZv1.R") # calc NHLBI BP Z using CDC HtZ

# read in spreadsheet with age (months), height (cm), and Sex (by default = M/F)
d<-read.csv("~/Desktop/NHANES2016/BP Jan 28/NHANESBP_Jan29.csv");
head(d) # display data


# Use CDC haz from SAS macro - Jan 29
tmp1<-bp_z(d, male="1", female="2", sbp="SBP", dbp="DBP", zht="haz", age="AGEMO", sex="SEX",  age.month=T);
head(tmp1) # display BP Z scores
dim(tmp1)
colnames(tmp1)<-c("CDC_sbp_z2", "CDC_dbp_z2")
d<-cbind(d,tmp1);head(d)


# use WHO zhfa/zlen from who2007/igrowup to calculate BP Z
tmp<-bp_z(d, male="1", female="2", sbp="SBP", dbp="DBP", zht="zhfa", age="AGEMO", sex="SEX",  age.month=T);
head(tmp) # display BP Z scores
dim(tmp)
colnames(tmp)<-c("WHO_sbp_z2", "WHO_dbp_z2")
d<-cbind(d,tmp);head(d)

with(d, describe(WHO_sbp_z2-WHO_sbp_z))
with(d, describe(CDC_sbp_z2-CDC_sbp_z))

write.csv(d, "~/Desktop/NHANES2016/BP Jan 28/out_NHANESBP_Jan29.csv", row.names=FALSE)
